==> igniteui-react-charts-18.6.0.tgz: package/esm2015/lib/igr-stacked-column-series.js <==
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedColumnSeries } from "./StackedColumnSeries";
/**
 * Represents a IgxDataChartComponent stacked column series.
*/
export class IgrStackedColumnSeries extends IgrHorizontalStackedSeriesBase {
    createImplementation() {
        return new StackedColumnSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a column shape.
    */
    get isColumn() {
        return this.i.ee;
    }
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.ez;
    }
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX() {
        return this.i.yn;
    }
    set radiusX(v) {
        this.i.yn = +v;
    }
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY() {
        return this.i.yo;
    }
    set radiusY(v) {
        this.i.yo = +v;
    }
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan() {
        let iv = this.i.h1();
        return (iv);
    }
}

==> igniteui-react-charts-18.7.2.tgz: package/esm2015/lib/igr-stacked-column-series.js <==
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedColumnSeries } from "./StackedColumnSeries";
/**
 * Represents a IgxDataChartComponent stacked column series.
*/
export class IgrStackedColumnSeries extends IgrHorizontalStackedSeriesBase {
    createImplementation() {
        return new StackedColumnSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a column shape.
    */
    get isColumn() {
        return this.i.ex;
    }
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.fj;
    }
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX() {
        return this.i.abl;
    }
    set radiusX(v) {
        this.i.abl = +v;
    }
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY() {
        return this.i.abm;
    }
    set radiusY(v) {
        this.i.abm = +v;
    }
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan() {
        let iv = this.i.iu();
        return (iv);
    }
}
